import { Directive, Pipe, Component, NgModule, Input, Output, } from '@angular/core';
import { reflectionCapabilities } from './ng-utils.mjs';
export const isDeclarable = (component) => {
    if (!component) {
        return false;
    }
    const decorators = reflectionCapabilities.annotations(component);
    return !!(decorators || []).find((d) => d instanceof Directive || d instanceof Pipe || d instanceof Component);
};
/**
 * Copied from Angular b/c they don't export this - https://github.com/angular/angular/blob/32ddac1fd6de42514c08830f5552e64c7945ea3e/packages/core/src/interface/type.ts#L21
 */
export const isType = (type) => {
    return typeof type === 'function';
};
export const isComponent = (component) => {
    if (!component || !isType(component)) {
        return false;
    }
    const decorators = reflectionCapabilities.annotations(component);
    return (decorators || []).some((d) => d instanceof Component);
};
export const isStandaloneComponent = (component) => {
    if (!component || !isType(component)) {
        return false;
    }
    const decorators = reflectionCapabilities.annotations(component);
    // TODO: `standalone` is only available in Angular v14. Remove cast to `any` once
    // Angular deps are updated to v14.x.x.
    return (decorators || []).some((d) => (d instanceof Component || d instanceof Directive || d instanceof Pipe) &&
        d.standalone);
};
export const isNgModule = (ngModule) => {
    const annotations = reflectionCapabilities.annotations(ngModule);
    return annotations.some((d) => d instanceof NgModule);
};
export const isInput = (input) => {
    return input instanceof Input;
};
export const isOutput = (output) => {
    return output instanceof Output;
};
//# sourceMappingURL=ng-type-guards.mjs.map