var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import '@angular/compiler';
import 'zone.js';
import { Component, isStandalone, importProvidersFrom, } from '@angular/core';
import { bootstrapApplication } from '@angular/platform-browser';
import { provideAnimations } from '@angular/platform-browser/animations';
import { getKsRendererClientUtils, showUiToastMsg, } from '@knapsack/renderer-webpack-base/client';
import { isObjectEmpty } from '@knapsack/utils';
import { isNgModule, isType } from '../analyze/utils/ng-type-guards.mjs';
import { rendererMetaScriptTagId, } from '../types.js';
import { analyzeComponent } from '../analyze/utils/ng-component-analyzer.mjs';
try {
    const { rendererMeta: { template, hasWrapper }, getExtraImports, getNeededImports, } = getKsRendererClientUtils({
        rendererMetaScriptTagId,
        assertImport: ({ imp, importInfo }) => {
            if (!isType(imp)) {
                if (importInfo.type === 'default') {
                    throw new Error(`Not an Angular component: the default export from "${importInfo.path}"`);
                }
                else {
                    throw new Error(`Not an Angular component: the named export "${importInfo.name}" from "${importInfo.path}"`);
                }
            }
        },
        assertExtraImport: ({ imp }) => {
            if (!isType(imp)) {
                throw new Error(`The "customNgModulePath" points to a file with a default export that is not a "NgModule"`);
            }
            if (!isNgModule(imp) && !isStandalone(imp)) {
                throw new Error(`Extra import must be either an NgModule or a standalone Component. Received: ${imp}`);
            }
        },
    });
    const componentClasses = Object.values(await getNeededImports());
    const standaloneComponentClasses = componentClasses.filter((c) => isStandalone(c));
    const { CustomNgModule: ngModule, WrapperComponent: wrapper } = await getExtraImports();
    // If the wrapper exists and is not empty, analyze it for a selector
    const selector = wrapper && !isObjectEmpty(wrapper) && analyzeComponent(wrapper).selector;
    if (!selector) {
        throw new Error('The provided wrapper component is missing a selector in its @Component decorator. Please ensure the component has a valid selector defined, for example: @Component({ selector: "my-wrapper" })');
    }
    const processedTemplate = hasWrapper
        ? `<${selector}>${template}</${selector}>`
        : template;
    let AppComponent = class AppComponent {
        // eslint-disable-next-line @typescript-eslint/class-methods-use-this
        logIt(name) {
            const msg = `Output: "${name}" happened`;
            console.log(msg);
            // this is debounced in UI
            showUiToastMsg({
                msg,
            });
        }
    };
    AppComponent = __decorate([
        Component({
            selector: 'ks-app-root',
            /**
             * This allows us to avoid using `NgModule`
             * Standalone components directly import other components, directives, and pipes used in their templates
             * https://angular.dev/guide/components/importing
             */
            standalone: true,
            imports: [
                ...(ngModule ? [ngModule] : []),
                ...(wrapper ? [wrapper] : []),
                ...standaloneComponentClasses,
            ],
            template: processedTemplate,
        })
    ], AppComponent);
    // Provide the browser animations provider here because the user can't load them
    // because the `BrowserModule` has already been loaded by the bootstrap process
    const _app = await bootstrapApplication(AppComponent, {
        // if custom ngModule exists, add its providers
        providers: ngModule
            ? [provideAnimations(), importProvidersFrom(ngModule)]
            : [provideAnimations()],
    });
    // console.log(_app);
}
catch (e) {
    console.error(e);
    // create html element with error message
    const errorElement = document.createElement('div');
    errorElement.innerHTML = `
    <h1>Error</h1>
    <p>${e.message}</p>
  `;
    document.body.appendChild(errorElement);
}
//# sourceMappingURL=init.mjs.map